@@ -19,6 +19,8 @@ from requests.adapters import HTTPAdapter
 
 logger = logging.getLogger(__name__)
 
+version = "0.9.8"
+
 
 class HttpSession(object):
     """
@@ -102,7 +104,8 @@ class HttpSession(object):
         # Build the access token request headers
         headers = {
             "X-LW-UAKS": self._api_secret,
-            "Content-Type": "application/json"
+            "Content-Type": "application/json",
+            "User-Agent": f"laceworksdk-python-client/{version}"
         }
 
         # Build the access token request data
@@ -114,6 +117,9 @@ class HttpSession(object):
         try:
             response = self._session.post(uri, json=data, headers=headers)
 
+            # Validate the response
+            self._check_response_code(response, DEFAULT_SUCCESS_RESPONSE_CODES)
+
             self._print_debug_logging(response)
 
         except Exception:
@@ -128,7 +134,8 @@ class HttpSession(object):
 
         # Build the request headers
         headers = {
-            "Authorization": self._access_token
+            "Authorization": self._access_token,
+            "User-Agent": f"laceworksdk-python-client/{version}"
         }
 
         return headers
